| Title: | Interactive 'shiny' Application for Model-Based Geostatistics |
|---|---|
| Description: | Provides an interactive 'shiny' application for teaching and applied analysis of geostatistical data. Users can explore spatial data, assess spatial correlation through the empirical variogram, fit model-based geostatistical models for continuous, prevalence and count outcomes, produce spatial predictions, and download reports. The methodology follows the model-based geostatistics framework of Diggle and Giorgi (2019, ISBN:9781138732353). |
| Authors: | Olatunji Johnson [cre, aut] (ORCID: <https://orcid.org/0000-0002-4080-0999>), Claudio Fronterre [aut], Emanuele Giorgi [aut] |
| Maintainer: | Olatunji Johnson <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.0 |
| Built: | 2026-07-10 21:48:09 UTC |
| Source: | https://github.com/cran/MBGapp |
Runs the interactive Shiny application for model-based geostatistical analysis that is bundled with the package. The application lets the user upload data, explore it, fit geostatistical models and produce predictions and reports.
run_app()run_app()
No return value; called for the side effect of launching the Shiny application.
if (interactive()) { run_app() }if (interactive()) { run_app() }